@@ -4,13 +4,13 @@ from pm4py.algo.discovery.dfg.utils.dfg_utils import get_activities_from_dfg, \
 from pm4py.algo.discovery.dfg.utils.dfg_utils import get_ingoing_edges, get_outgoing_edges
 from pm4py.algo.discovery.dfg.utils.dfg_utils import negate, get_activities_self_loop, transform_dfg_to_directed_nx_graph
 from pm4py.algo.discovery.dfg.variants import native as dfg_inst
-from pm4py.algo.filtering.dfg.dfg_filtering import clean_dfg_based_on_noise_thresh
+from pm4py.objects.dfg.filtering.dfg_filtering import clean_dfg_based_on_noise_thresh
 from pm4py.algo.discovery.inductive.variants.im.util import base_case
 from pm4py import util as pmutil
 from pm4py.algo.discovery.inductive.variants.im.util import splitting as split
-from pm4py.algo.filtering.log.attributes import attributes_filter
-from pm4py.algo.filtering.log.end_activities import end_activities_filter
-from pm4py.algo.filtering.log.start_activities import start_activities_filter
+from pm4py.statistics.attributes.log import get as attributes_get
+from pm4py.statistics.end_activities.log import get as end_activities_get
+from pm4py.statistics.start_activities.log import get  as start_activities_get
 from pm4py.algo.discovery.inductive.util import parallel_cut_utils, detection_utils, cut_detection
 from pm4py.algo.discovery.inductive.variants.im_f import splitting_infrequent, fall_through_infrequent
 from pm4py.algo.discovery.inductive.variants.im.util import fall_through
@@ -232,8 +232,8 @@ class SubtreeInfrequent(object):
         if self.contains_empty_trace():
             return [False, []]
         start_activities = list(
-            start_activities_filter.get_start_activities(self.log, parameters=self.parameters).keys())
-        end_activities = list(end_activities_filter.get_end_activities(self.log, parameters=self.parameters).keys())
+            start_activities_get.get_start_activities(self.log, parameters=self.parameters).keys())
+        end_activities = list(end_activities_get.get_end_activities(self.log, parameters=self.parameters).keys())
         p1 = []
         for act in start_activities:
             if act not in p1:
@@ -398,11 +398,11 @@ class SubtreeInfrequent(object):
             new_logs = split.split_xor(cut[1], self.log, activity_key)
             for l in new_logs:
                 new_dfg = [(k, v) for k, v in dfg_inst.apply(l, parameters=self.parameters).items() if v > 0]
-                activities = attributes_filter.get_attribute_values(l, activity_key)
+                activities = attributes_get.get_attribute_values(l, activity_key)
                 start_activities = list(
-                    start_activities_filter.get_start_activities(l, parameters=self.parameters).keys())
+                    start_activities_get.get_start_activities(l, parameters=self.parameters).keys())
                 end_activities = list(
-                    end_activities_filter.get_end_activities(l, parameters=self.parameters).keys())
+                    end_activities_get.get_end_activities(l, parameters=self.parameters).keys())
                 self.children.append(
                     SubtreeInfrequent(l, new_dfg, self.master_dfg, self.initial_dfg, activities, self.counts,
                                       self.rec_depth + 1, self.f,
@@ -415,11 +415,11 @@ class SubtreeInfrequent(object):
             self.detected_cut = "sequential"
             for l in new_logs:
                 new_dfg = [(k, v) for k, v in dfg_inst.apply(l, parameters=self.parameters).items() if v > 0]
-                activities = attributes_filter.get_attribute_values(l, activity_key)
+                activities = attributes_get.get_attribute_values(l, activity_key)
                 start_activities = list(
-                    start_activities_filter.get_start_activities(l, parameters=self.parameters).keys())
+                    start_activities_get.get_start_activities(l, parameters=self.parameters).keys())
                 end_activities = list(
-                    end_activities_filter.get_end_activities(l, parameters=self.parameters).keys())
+                    end_activities_get.get_end_activities(l, parameters=self.parameters).keys())
                 self.children.append(
                     SubtreeInfrequent(l, new_dfg, self.master_dfg, self.initial_dfg, activities, self.counts,
                                       self.rec_depth + 1, self.f,
@@ -432,11 +432,11 @@ class SubtreeInfrequent(object):
             self.detected_cut = "parallel"
             for l in new_logs:
                 new_dfg = [(k, v) for k, v in dfg_inst.apply(l, parameters=self.parameters).items() if v > 0]
-                activities = attributes_filter.get_attribute_values(l, activity_key)
+                activities = attributes_get.get_attribute_values(l, activity_key)
                 start_activities = list(
-                    start_activities_filter.get_start_activities(l, parameters=self.parameters).keys())
+                    start_activities_get.get_start_activities(l, parameters=self.parameters).keys())
                 end_activities = list(
-                    end_activities_filter.get_end_activities(l, parameters=self.parameters).keys())
+                    end_activities_get.get_end_activities(l, parameters=self.parameters).keys())
                 self.children.append(
                     SubtreeInfrequent(l, new_dfg, self.master_dfg, self.initial_dfg, activities, self.counts,
                                       self.rec_depth + 1, self.f,
@@ -449,11 +449,11 @@ class SubtreeInfrequent(object):
             self.detected_cut = "loopCut"
             for l in new_logs:
                 new_dfg = [(k, v) for k, v in dfg_inst.apply(l, parameters=self.parameters).items() if v > 0]
-                activities = attributes_filter.get_attribute_values(l, activity_key)
+                activities = attributes_get.get_attribute_values(l, activity_key)
                 start_activities = list(
-                    start_activities_filter.get_start_activities(l, parameters=self.parameters).keys())
+                    start_activities_get.get_start_activities(l, parameters=self.parameters).keys())
                 end_activities = list(
-                    end_activities_filter.get_end_activities(l, parameters=self.parameters).keys())
+                    end_activities_get.get_end_activities(l, parameters=self.parameters).keys())
                 self.children.append(
                     SubtreeInfrequent(l, new_dfg, self.master_dfg, self.initial_dfg, activities, self.counts,
                                       self.rec_depth + 1, self.f,
@@ -494,11 +494,11 @@ class SubtreeInfrequent(object):
                         new_logs = splitting_infrequent.split_xor_infrequent(cut[1], self.log, activity_key)
                         for l in new_logs:
                             new_dfg = [(k, v) for k, v in dfg_inst.apply(l, parameters=parameters).items() if v > 0]
-                            activities = attributes_filter.get_attribute_values(l, activity_key)
+                            activities = attributes_get.get_attribute_values(l, activity_key)
                             start_activities = list(
-                                start_activities_filter.get_start_activities(l, parameters=parameters).keys())
+                                start_activities_get.get_start_activities(l, parameters=parameters).keys())
                             end_activities = list(
-                                end_activities_filter.get_end_activities(l, parameters=parameters).keys())
+                                end_activities_get.get_end_activities(l, parameters=parameters).keys())
                             self.children.append(
                                 SubtreeInfrequent(l, new_dfg, self.master_dfg, self.initial_dfg, activities,
                                                   self.counts,
@@ -515,11 +515,11 @@ class SubtreeInfrequent(object):
                         self.detected_cut = "sequential"
                         for l in new_logs:
                             new_dfg = [(k, v) for k, v in dfg_inst.apply(l, parameters=parameters).items() if v > 0]
-                            activities = attributes_filter.get_attribute_values(l, activity_key)
+                            activities = attributes_get.get_attribute_values(l, activity_key)
                             start_activities = list(
-                                start_activities_filter.get_start_activities(l, parameters=parameters).keys())
+                                start_activities_get.get_start_activities(l, parameters=parameters).keys())
                             end_activities = list(
-                                end_activities_filter.get_end_activities(l, parameters=parameters).keys())
+                                end_activities_get.get_end_activities(l, parameters=parameters).keys())
                             self.children.append(
                                 SubtreeInfrequent(l, new_dfg, self.master_dfg, self.initial_dfg, activities,
                                                   self.counts,
@@ -536,11 +536,11 @@ class SubtreeInfrequent(object):
                         self.detected_cut = "parallel"
                         for l in new_logs:
                             new_dfg = [(k, v) for k, v in dfg_inst.apply(l, parameters=parameters).items() if v > 0]
-                            activities = attributes_filter.get_attribute_values(l, activity_key)
+                            activities = attributes_get.get_attribute_values(l, activity_key)
                             start_activities = list(
-                                start_activities_filter.get_start_activities(l, parameters=parameters).keys())
+                                start_activities_get.get_start_activities(l, parameters=parameters).keys())
                             end_activities = list(
-                                end_activities_filter.get_end_activities(l, parameters=parameters).keys())
+                                end_activities_get.get_end_activities(l, parameters=parameters).keys())
                             self.children.append(
                                 SubtreeInfrequent(l, new_dfg, self.master_dfg, self.initial_dfg, activities,
                                                   self.counts,
@@ -557,11 +557,11 @@ class SubtreeInfrequent(object):
                         self.detected_cut = "loopCut"
                         for l in new_logs:
                             new_dfg = [(k, v) for k, v in dfg_inst.apply(l, parameters=parameters).items() if v > 0]
-                            activities = attributes_filter.get_attribute_values(l, activity_key)
+                            activities = attributes_get.get_attribute_values(l, activity_key)
                             start_activities = list(
-                                start_activities_filter.get_start_activities(l, parameters=parameters).keys())
+                                start_activities_get.get_start_activities(l, parameters=parameters).keys())
                             end_activities = list(
-                                end_activities_filter.get_end_activities(l, parameters=parameters).keys())
+                                end_activities_get.get_end_activities(l, parameters=parameters).keys())
                             self.children.append(
                                 SubtreeInfrequent(l, new_dfg, self.master_dfg, self.initial_dfg, activities,
                                                   self.counts,
@@ -604,11 +604,11 @@ class SubtreeInfrequent(object):
             logging.debug("empty_trace_if")
             self.detected_cut = 'empty_trace'
             new_dfg = [(k, v) for k, v in dfg_inst.apply(new_log, parameters=self.parameters).items() if v > 0]
-            activities = attributes_filter.get_attribute_values(new_log, activity_key)
+            activities = attributes_get.get_attribute_values(new_log, activity_key)
             start_activities = list(
-                                start_activities_filter.get_start_activities(new_log, parameters=parameters).keys())
+                                start_activities_get.get_start_activities(new_log, parameters=parameters).keys())
             end_activities = list(
-                                end_activities_filter.get_end_activities(new_log, parameters=parameters).keys())
+                                end_activities_get.get_end_activities(new_log, parameters=parameters).keys())
             self.children.append(
                 SubtreeInfrequent(new_log, new_dfg, self.master_dfg, self.initial_dfg, activities, self.counts,
                                   self.rec_depth + 1, self.f,
@@ -630,14 +630,14 @@ class SubtreeInfrequent(object):
                 # create two new dfgs as we need them to append to self.children later
                 new_dfg = [(k, v) for k, v in dfg_inst.apply(new_log, parameters=parameters).items() if
                            v > 0]
-                activities = attributes_filter.get_attribute_values(new_log, activity_key)
+                activities = attributes_get.get_attribute_values(new_log, activity_key)
                 small_dfg = [(k, v) for k, v in dfg_inst.apply(small_log, parameters=parameters).items() if
                              v > 0]
-                small_activities = attributes_filter.get_attribute_values(small_log, activity_key)
+                small_activities = attributes_get.get_attribute_values(small_log, activity_key)
                 start_activities = list(
-                                start_activities_filter.get_start_activities(new_log, parameters=parameters).keys())
+                                start_activities_get.get_start_activities(new_log, parameters=parameters).keys())
                 end_activities = list(
-                                end_activities_filter.get_end_activities(new_log, parameters=parameters).keys())
+                                end_activities_get.get_end_activities(new_log, parameters=parameters).keys())
                 # append the chosen activity as leaf:
                 self.children.append(
                     SubtreeInfrequent(small_log, small_dfg, self.master_dfg, self.initial_dfg, small_activities,
@@ -670,14 +670,14 @@ class SubtreeInfrequent(object):
                     # create two new dfgs on to append later
                     new_dfg = [(k, v) for k, v in dfg_inst.apply(new_log, parameters=parameters).items() if
                                v > 0]
-                    activities = attributes_filter.get_attribute_values(new_log, activity_key)
+                    activities = attributes_get.get_attribute_values(new_log, activity_key)
                     small_dfg = [(k, v) for k, v in dfg_inst.apply(small_log, parameters=parameters).items() if
                                  v > 0]
-                    small_activities = attributes_filter.get_attribute_values(small_log, activity_key)
+                    small_activities = attributes_get.get_attribute_values(small_log, activity_key)
                     start_activities = list(
-                                start_activities_filter.get_start_activities(new_log, parameters=parameters).keys())
+                                start_activities_get.get_start_activities(new_log, parameters=parameters).keys())
                     end_activities = list(
-                                end_activities_filter.get_end_activities(new_log, parameters=parameters).keys())
+                                end_activities_get.get_end_activities(new_log, parameters=parameters).keys())
                     # append the concurrent activity as leaf:
                     self.children.append(
                         SubtreeInfrequent(small_log, small_dfg, self.master_dfg, self.initial_dfg,
@@ -708,11 +708,11 @@ class SubtreeInfrequent(object):
                         self.detected_cut = 'strict_tau_loop'
                         new_dfg = [(k, v) for k, v in dfg_inst.apply(new_log, parameters=parameters).items() if
                                    v > 0]
-                        activities = attributes_filter.get_attribute_values(new_log, activity_key)
+                        activities = attributes_get.get_attribute_values(new_log, activity_key)
                         start_activities = list(
-                                start_activities_filter.get_start_activities(new_log, parameters=parameters).keys())
+                                start_activities_get.get_start_activities(new_log, parameters=parameters).keys())
                         end_activities = list(
-                                end_activities_filter.get_end_activities(new_log, parameters=parameters).keys())
+                                end_activities_get.get_end_activities(new_log, parameters=parameters).keys())
                         self.children.append(
                             SubtreeInfrequent(new_log, new_dfg, self.master_dfg, self.initial_dfg,
                                               activities,
@@ -733,11 +733,11 @@ class SubtreeInfrequent(object):
                             self.detected_cut = 'tau_loop'
                             new_dfg = [(k, v) for k, v in dfg_inst.apply(new_log, parameters=parameters).items() if
                                        v > 0]
-                            activities = attributes_filter.get_attribute_values(new_log, activity_key)
+                            activities = attributes_get.get_attribute_values(new_log, activity_key)
                             start_activities = list(
-                                start_activities_filter.get_start_activities(new_log, parameters=parameters).keys())
+                                start_activities_get.get_start_activities(new_log, parameters=parameters).keys())
                             end_activities = list(
-                                end_activities_filter.get_end_activities(new_log, parameters=parameters).keys())
+                                end_activities_get.get_end_activities(new_log, parameters=parameters).keys())
                             self.children.append(
                                 SubtreeInfrequent(new_log, new_dfg, self.master_dfg, self.initial_dfg,
                                                   activities,
