@@ -1,18 +1,18 @@
+from enum import Enum
+
+from pm4py.statistics.attributes.log.select import *
+from pm4py.statistics.attributes.log.get import *
 from pm4py.algo.filtering.common import filtering_constants
-from pm4py.statistics.attributes.common import get as attributes_common
-from pm4py.statistics.attributes.log.get import get_attribute_values, get_all_event_attributes_from_log, \
-    get_all_trace_attributes_from_log, get_kde_date_attribute, get_kde_date_attribute_json, get_kde_numeric_attribute, \
-    get_kde_numeric_attribute_json, get_trace_attribute_values
-from pm4py.statistics.attributes.log.select import select_attributes_from_log_for_tree
 from pm4py.algo.filtering.log.variants import variants_filter
 from pm4py.objects.conversion.log import converter as log_converter
 from pm4py.objects.log.log import EventLog, Trace, EventStream
+from pm4py.statistics.attributes.common import get as attributes_common
+from pm4py.statistics.attributes.log.get import get_attribute_values
+from pm4py.util import exec_utils
 from pm4py.util import xes_constants as xes
-from pm4py.util.xes_constants import DEFAULT_NAME_KEY
 from pm4py.util.constants import PARAMETER_CONSTANT_ATTRIBUTE_KEY, PARAMETER_CONSTANT_ACTIVITY_KEY
 from pm4py.util.constants import PARAMETER_CONSTANT_CASEID_KEY
-from enum import Enum
-from pm4py.util import exec_utils
+from pm4py.util.xes_constants import DEFAULT_NAME_KEY
 
 
 class Parameters(Enum):
@@ -64,20 +64,29 @@ def apply_numeric(log, int1, int2, parameters=None):
     stream = log_converter.apply(log, variant=log_converter.TO_EVENT_STREAM)
     if stream_filter_key1 is not None:
         stream = EventStream(
-            list(filter(lambda x: stream_filter_key1 in x and x[stream_filter_key1] == stream_filter_value1, stream)))
+            list(filter(lambda x: stream_filter_key1 in x and x[stream_filter_key1] == stream_filter_value1, stream)),
+            attributes=log.attributes, extensions=log.extensions, classifiers=log.classifiers,
+            omni_present=log.omni_present)
     if stream_filter_key2 is not None:
         stream = EventStream(
-            list(filter(lambda x: stream_filter_key2 in x and x[stream_filter_key2] == stream_filter_value2, stream)))
+            list(filter(lambda x: stream_filter_key2 in x and x[stream_filter_key2] == stream_filter_value2, stream)),
+            attributes=log.attributes, extensions=log.extensions, classifiers=log.classifiers,
+            omni_present=log.omni_present)
 
     if positive:
-        stream = EventStream(list(filter(lambda x: attribute_key in x and int1 <= x[attribute_key] <= int2, stream)))
+        stream = EventStream(list(filter(lambda x: attribute_key in x and int1 <= x[attribute_key] <= int2, stream)),
+                             attributes=log.attributes, extensions=log.extensions, classifiers=log.classifiers,
+                             omni_present=log.omni_present)
     else:
         stream = EventStream(
-            list(filter(lambda x: attribute_key in x and (x[attribute_key] < int1 or x[attribute_key] > int2), stream)))
+            list(filter(lambda x: attribute_key in x and (x[attribute_key] < int1 or x[attribute_key] > int2), stream)),
+            attributes=log.attributes, extensions=log.extensions, classifiers=log.classifiers,
+            omni_present=log.omni_present)
 
     all_cases_ids = set(x["case:" + case_key] for x in stream)
 
-    filtered_log = EventLog()
+    filtered_log = EventLog(list(), attributes=log.attributes, extensions=log.extensions, classifiers=log.classifiers,
+                            omni_present=log.omni_present)
 
     for case in log:
         if case.attributes[case_key] in all_cases_ids:
@@ -112,15 +121,17 @@ def apply_numeric_events(log, int1, int2, parameters=None):
         parameters = {}
 
     attribute_key = exec_utils.get_param_value(Parameters.ATTRIBUTE_KEY, parameters, DEFAULT_NAME_KEY)
-    positive = exec_utils.get_param_value(Parameters.POSITIVE, parameters, True)
 
     stream = log_converter.apply(log, variant=log_converter.TO_EVENT_STREAM)
-    if positive:
-        stream = EventStream(list(filter(lambda x: attribute_key in x and int1 <= x[attribute_key] <= int2, stream)))
+    if exec_utils.get_param_value(Parameters.POSITIVE, parameters, True):
+        stream = EventStream(list(filter(lambda x: attribute_key in x and int1 <= x[attribute_key] <= int2, stream)),
+                             attributes=log.attributes, extensions=log.extensions, classifiers=log.classifiers,
+                             omni_present=log.omni_present)
     else:
         stream = EventStream(
-            list(filter(lambda x: attribute_key in x and (x[attribute_key] < int1 or x[attribute_key] > int2), stream)))
-
+            list(filter(lambda x: attribute_key in x and (x[attribute_key] < int1 or x[attribute_key] > int2), stream)),
+            attributes=log.attributes, extensions=log.extensions, classifiers=log.classifiers,
+            omni_present=log.omni_present)
     filtered_log = log_converter.apply(stream)
 
     return filtered_log
@@ -154,9 +165,13 @@ def apply_events(log, values, parameters=None):
 
     stream = log_converter.apply(log, variant=log_converter.TO_EVENT_STREAM)
     if positive:
-        stream = EventStream(list(filter(lambda x: x[attribute_key] in values, stream)))
+        stream = EventStream(list(filter(lambda x: x[attribute_key] in values, stream)), attributes=log.attributes,
+                             extensions=log.extensions, classifiers=log.classifiers,
+                             omni_present=log.omni_present)
     else:
-        stream = EventStream(list(filter(lambda x: x[attribute_key] not in values, stream)))
+        stream = EventStream(list(filter(lambda x: x[attribute_key] not in values, stream)), attributes=log.attributes,
+                             extensions=log.extensions, classifiers=log.classifiers,
+                             omni_present=log.omni_present)
 
     filtered_log = log_converter.apply(stream)
 
@@ -190,7 +205,8 @@ def apply(log, values, parameters=None):
     attribute_key = exec_utils.get_param_value(Parameters.ATTRIBUTE_KEY, parameters, DEFAULT_NAME_KEY)
     positive = exec_utils.get_param_value(Parameters.POSITIVE, parameters, True)
 
-    filtered_log = EventLog()
+    filtered_log = EventLog(list(), attributes=log.attributes, extensions=log.extensions, classifiers=log.classifiers,
+                            omni_present=log.omni_present)
     for trace in log:
         new_trace = Trace()
 
@@ -238,7 +254,8 @@ def apply_trace_attribute(log, values, parameters=None):
     attribute_key = exec_utils.get_param_value(Parameters.ATTRIBUTE_KEY, parameters, DEFAULT_NAME_KEY)
     positive = exec_utils.get_param_value(Parameters.POSITIVE, parameters, True)
 
-    filtered_log = EventLog()
+    filtered_log = EventLog(list(), attributes=log.attributes, extensions=log.extensions, classifiers=log.classifiers,
+                            omni_present=log.omni_present)
     for trace in log:
         if positive:
             if attribute_key in trace.attributes and trace.attributes[attribute_key] in values:
@@ -307,7 +324,8 @@ def filter_log_by_attributes_threshold(log, attributes, variants, vc, threshold,
     filtered_log
         Filtered log
     """
-    filtered_log = EventLog()
+    filtered_log = EventLog(list(), attributes=log.attributes, extensions=log.extensions, classifiers=log.classifiers,
+                            omni_present=log.omni_present)
     fva = [x[attribute_key] for x in variants[vc[0][0]][0] if attribute_key in x]
     for trace in log:
         new_trace = Trace()
