@@ -1,10 +1,11 @@
+from enum import Enum
+
 from pm4py.algo.filtering.common.timestamp.timestamp_common import get_dt_from_string
 from pm4py.objects.conversion.log import converter as log_converter
 from pm4py.objects.log.log import EventLog, EventStream
-from pm4py.util.xes_constants import DEFAULT_TIMESTAMP_KEY
-from pm4py.util.constants import PARAMETER_CONSTANT_TIMESTAMP_KEY
-from enum import Enum
 from pm4py.util import exec_utils
+from pm4py.util.constants import PARAMETER_CONSTANT_TIMESTAMP_KEY
+from pm4py.util.xes_constants import DEFAULT_TIMESTAMP_KEY
 
 
 class Parameters(Enum):
@@ -32,7 +33,7 @@ def is_contained(trace, dt1, dt2, timestamp_key):
         Is true if the trace is contained
     """
     if trace:
-        if trace[0][timestamp_key].replace(tzinfo=None) > dt1 and trace[-1][timestamp_key].replace(tzinfo=None) < dt2:
+        if trace[0][timestamp_key].replace(tzinfo=None) >= dt1 and trace[-1][timestamp_key].replace(tzinfo=None) <= dt2:
             return True
     return False
 
@@ -63,7 +64,9 @@ def filter_traces_contained(log, dt1, dt2, parameters=None):
     timestamp_key = exec_utils.get_param_value(Parameters.TIMESTAMP_KEY, parameters, DEFAULT_TIMESTAMP_KEY)
     dt1 = get_dt_from_string(dt1)
     dt2 = get_dt_from_string(dt2)
-    filtered_log = EventLog([trace for trace in log if is_contained(trace, dt1, dt2, timestamp_key)])
+    filtered_log = EventLog([trace for trace in log if is_contained(trace, dt1, dt2, timestamp_key)],
+                            attributes=log.attributes, extensions=log.extensions, omni_present=log.omni_present,
+                            classifiers=log.classifiers)
     return filtered_log
 
 
@@ -88,10 +91,10 @@ def is_intersecting(trace, dt1, dt2, timestamp_key):
         Is true if the trace is contained
     """
     if trace:
-        condition1 = dt1 < trace[0][timestamp_key].replace(tzinfo=None) < dt2
-        condition2 = dt1 < trace[-1][timestamp_key].replace(tzinfo=None) < dt2
-        condition3 = trace[0][timestamp_key].replace(tzinfo=None) < dt1 < trace[-1][timestamp_key].replace(tzinfo=None)
-        condition4 = trace[0][timestamp_key].replace(tzinfo=None) < dt2 < trace[-1][timestamp_key].replace(tzinfo=None)
+        condition1 = dt1 <= trace[0][timestamp_key].replace(tzinfo=None) <= dt2
+        condition2 = dt1 <= trace[-1][timestamp_key].replace(tzinfo=None) <= dt2
+        condition3 = trace[0][timestamp_key].replace(tzinfo=None) <= dt1 <= trace[-1][timestamp_key].replace(tzinfo=None)
+        condition4 = trace[0][timestamp_key].replace(tzinfo=None) <= dt2 <= trace[-1][timestamp_key].replace(tzinfo=None)
 
         if condition1 or condition2 or condition3 or condition4:
             return True
@@ -125,7 +128,9 @@ def filter_traces_intersecting(log, dt1, dt2, parameters=None):
         PARAMETER_CONSTANT_TIMESTAMP_KEY] if PARAMETER_CONSTANT_TIMESTAMP_KEY in parameters else DEFAULT_TIMESTAMP_KEY
     dt1 = get_dt_from_string(dt1)
     dt2 = get_dt_from_string(dt2)
-    filtered_log = EventLog([trace for trace in log if is_intersecting(trace, dt1, dt2, timestamp_key)])
+    filtered_log = EventLog([trace for trace in log if is_intersecting(trace, dt1, dt2, timestamp_key)],
+                            attributes=log.attributes, extensions=log.extensions, omni_present=log.omni_present,
+                            classifiers=log.classifiers)
     return filtered_log
 
 
@@ -157,7 +162,9 @@ def apply_events(log, dt1, dt2, parameters=None):
     dt2 = get_dt_from_string(dt2)
 
     stream = log_converter.apply(log, variant=log_converter.TO_EVENT_STREAM)
-    filtered_stream = EventStream([x for x in stream if dt1 < x[timestamp_key].replace(tzinfo=None) < dt2])
+    filtered_stream = EventStream([x for x in stream if dt1 <= x[timestamp_key].replace(tzinfo=None) <= dt2],
+                                  attributes=log.attributes, extensions=log.extensions, omni_present=log.omni_present,
+                                  classifiers=log.classifiers)
     filtered_log = log_converter.apply(filtered_stream)
 
     return filtered_log
