@@ -1,5 +1,6 @@
 from pm4py.objects.bpmn.bpmn_graph import BPMN
 from pm4py.util import constants
+import uuid
 
 
 class Counts:
@@ -28,21 +29,21 @@ def parse_element(bpmn_graph, counts, curr_el, parents, incoming_dict, outgoing_
         nodes_dict[id] = node
     elif tag.endswith("startevent"):
         id = curr_el.get("id")
-        name = curr_el.get("name").replace("\r", " ").replace("\n", " ")
+        name = curr_el.get("name").replace("\r", " ").replace("\n", " ") if "name" in curr_el else str(uuid.uuid4())
         start_event = BPMN.StartEvent(name=name)
         bpmn_graph.add_node(start_event)
         node = start_event
         nodes_dict[id] = node
     elif tag.endswith("endevent"):
         id = curr_el.get("id")
-        name = curr_el.get("name").replace("\r", " ").replace("\n", " ")
+        name = curr_el.get("name").replace("\r", " ").replace("\n", " ") if "name" in curr_el else str(uuid.uuid4())
         end_event = BPMN.EndEvent(name=name)
         bpmn_graph.add_node(end_event)
         node = end_event
         nodes_dict[id] = node
     elif tag.endswith("event"):
         id = curr_el.get("id")
-        name = curr_el.get("name").replace("\r", " ").replace("\n", " ")
+        name = curr_el.get("name").replace("\r", " ").replace("\n", " ") if "name" in curr_el else str(uuid.uuid4())
         this_type = str(curr_el.tag)
         this_type = this_type[this_type.index("}") + 1:]
         other_event = BPMN.OtherEvent(name=name, type=this_type)
@@ -54,21 +55,21 @@ def parse_element(bpmn_graph, counts, curr_el, parents, incoming_dict, outgoing_
         flow = bpmnElement
     elif tag.endswith("exclusivegateway"):
         id = curr_el.get("id")
-        name = curr_el.get("name").replace("\r", "").replace("\n", "")
+        name = curr_el.get("name").replace("\r", "").replace("\n", "") if "name" in curr_el else str(uuid.uuid4())
         exclusive_gateway = BPMN.ExclusiveGateway(name=name)
         bpmn_graph.add_node(exclusive_gateway)
         node = exclusive_gateway
         nodes_dict[id] = node
     elif tag.endswith("parallelgateway"):
         id = curr_el.get("id")
-        name = curr_el.get("name").replace("\r", "").replace("\n", "")
+        name = curr_el.get("name").replace("\r", "").replace("\n", "") if "name" in curr_el else str(uuid.uuid4())
         parallel_gateway = BPMN.ParallelGateway(name=name)
         bpmn_graph.add_node(parallel_gateway)
         node = parallel_gateway
         nodes_dict[id] = node
     elif tag.endswith("inclusivegateway"):
         id = curr_el.get("id")
-        name = curr_el.get("name").replace("\r", "").replace("\n", "")
+        name = curr_el.get("name").replace("\r", "").replace("\n", "") if "name" in curr_el else str(uuid.uuid4())
         inclusive_gateway = BPMN.InclusiveGateway(name=name)
         bpmn_graph.add_node(inclusive_gateway)
         node = inclusive_gateway
