@@ -1,6 +1,8 @@
-from pm4py.objects.petri import common, incidence_matrix, petrinet, \
-    reachability_graph, semantics, synchronous_product, utils, check_soundness, networkx_graph, align_utils, explore_path, performance_map, embed_stochastic_map
 import pkgutil
 
+from pm4py.objects.petri import common, incidence_matrix, petrinet, \
+    reachability_graph, semantics, synchronous_product, utils, check_soundness, networkx_graph, align_utils, \
+    explore_path, performance_map, embed_stochastic_map, reduction
+
 if pkgutil.find_loader("lxml"):
     from pm4py.objects.petri import exporter, importer
