@@ -1,8 +1,10 @@
 import uuid
 
 from lxml import etree
-from pm4py.objects.process_tree.pt_operator import Operator
+
 from pm4py.objects.process_tree.process_tree import ProcessTree
+from pm4py.objects.process_tree.pt_operator import Operator
+from pm4py.util import constants
 
 
 def get_list_nodes_from_tree(tree, parameters=None):
@@ -136,7 +138,7 @@ def export_tree_as_string(tree, parameters=None):
     # gets the XML tree
     tree = export_ptree_tree(tree, parameters=parameters)
 
-    return etree.tostring(tree, xml_declaration=True, encoding="utf-8").decode('utf-8')
+    return etree.tostring(tree, xml_declaration=True, encoding=constants.DEFAULT_ENCODING)
 
 
 def apply(tree, output_path, parameters=None):
@@ -159,6 +161,6 @@ def apply(tree, output_path, parameters=None):
     tree = export_ptree_tree(tree, parameters=parameters)
 
     # exports the tree to a file
-    tree.write(output_path, pretty_print=True, xml_declaration=True, encoding="utf-8")
+    tree.write(output_path, pretty_print=True, xml_declaration=True, encoding=constants.DEFAULT_ENCODING)
 
     return tree
