@@ -1,22 +1,23 @@
 import datetime
 from copy import copy
-from random import choice
+from enum import Enum
 
 from pm4py.objects.log import log as log_instance
 from pm4py.objects.petri import semantics
+from pm4py.objects.petri.common import final_marking as final_marking_discovery
+from pm4py.objects.petri.petrinet import PetriNet
+from pm4py.objects.stochastic_petri import utils as stochastic_utils
+from pm4py.simulation.montecarlo.utils import replay
+from pm4py.util import constants
 from pm4py.util import exec_utils
 from pm4py.util import xes_constants
-from enum import Enum
-from pm4py.util import constants
-from pm4py.simulation.montecarlo.utils import replay
-from pm4py.objects.petri.common import final_marking as final_marking_discovery
-from pm4py.objects.stochastic_petri import utils as stochastic_utils
 
 
 class Parameters(Enum):
     ACTIVITY_KEY = constants.PARAMETER_CONSTANT_ACTIVITY_KEY
     TIMESTAMP_KEY = constants.PARAMETER_CONSTANT_TIMESTAMP_KEY
     CASE_ID_KEY = constants.PARAMETER_CONSTANT_CASEID_KEY
+    RETURN_VISITED_ELEMENTS = "return_visited_elements"
     NO_TRACES = "noTraces"
     MAX_TRACE_LENGTH = "maxTraceLength"
     LOG = "log"
@@ -26,7 +27,7 @@ class Parameters(Enum):
 def apply_playout(net, initial_marking, no_traces=100, max_trace_length=100,
                   case_id_key=xes_constants.DEFAULT_TRACEID_KEY,
                   activity_key=xes_constants.DEFAULT_NAME_KEY, timestamp_key=xes_constants.DEFAULT_TIMESTAMP_KEY,
-                  final_marking=None, smap=None, log=None):
+                  final_marking=None, smap=None, log=None, return_visited_elements=False):
     """
     Do the playout of a Petrinet generating a log
 
@@ -64,12 +65,16 @@ def apply_playout(net, initial_marking, no_traces=100, max_trace_length=100,
                                                            Parameters.TIMESTAMP_KEY: timestamp_key})
     # assigns to each event an increased timestamp from 1970
     curr_timestamp = 10000000
-    log = log_instance.EventLog()
+    all_visited_elements = []
+
     for i in range(no_traces):
-        trace = log_instance.Trace()
-        trace.attributes[case_id_key] = str(i)
+        visited_elements = []
+        visible_transitions_visited = []
         marking = copy(initial_marking)
-        while len(trace) < max_trace_length:
+
+        while len(visible_transitions_visited) < max_trace_length:
+            visited_elements.append(marking)
+
             if not semantics.enabled_transitions(net, marking):  # supports nets with possible deadlocks
                 break
             all_enabled_trans = semantics.enabled_transitions(net, marking)
@@ -82,15 +87,33 @@ def apply_playout(net, initial_marking, no_traces=100, max_trace_length=100,
 
             if trans is None:
                 break
+
+            visited_elements.append(trans)
             if trans.label is not None:
+                visible_transitions_visited.append(trans)
+
+            marking = semantics.execute(trans, net, marking)
+
+        all_visited_elements.append(tuple(visited_elements))
+
+    if return_visited_elements:
+        return all_visited_elements
+
+    log = log_instance.EventLog()
+
+    for index, visited_elements in enumerate(all_visited_elements):
+        trace = log_instance.Trace()
+        trace.attributes[case_id_key] = str(index)
+        for element in visited_elements:
+            if type(element) is PetriNet.Transition and element.label is not None:
                 event = log_instance.Event()
-                event[activity_key] = trans.label
+                event[activity_key] = element.label
                 event[timestamp_key] = datetime.datetime.fromtimestamp(curr_timestamp)
                 trace.append(event)
                 # increases by 1 second
                 curr_timestamp += 1
-            marking = semantics.execute(trans, net, marking)
         log.append(trace)
+
     return log
 
 
@@ -121,7 +144,8 @@ def apply(net, initial_marking, final_marking=None, parameters=None):
     max_trace_length = exec_utils.get_param_value(Parameters.MAX_TRACE_LENGTH, parameters, 1000)
     smap = exec_utils.get_param_value(Parameters.STOCHASTIC_MAP, parameters, None)
     log = exec_utils.get_param_value(Parameters.LOG, parameters, None)
+    return_visited_elements = exec_utils.get_param_value(Parameters.RETURN_VISITED_ELEMENTS, parameters, False)
 
     return apply_playout(net, initial_marking, max_trace_length=max_trace_length, no_traces=no_traces,
                          case_id_key=case_id_key, activity_key=activity_key, timestamp_key=timestamp_key,
-                         final_marking=final_marking, smap=smap, log=log)
+                         final_marking=final_marking, smap=smap, log=log, return_visited_elements=return_visited_elements)
